/*
 * iweather.c
 *
 * Copyright (C) 2006 Terry Stenvold & Felix Bruns
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>
#include <dirent.h>
#include <errno.h>
#include "pz.h"

static PzModule *module;
static PzConfig *config;
static TWindow *window;
static TWindow *viewer_window;
static TWidget *viewer;
static TWidget *menu;
static ttk_surface image;

static int file_exists(char *path);

//static const char* loading_options[] = { "/iweather", "/mnt/iweather", NULL };

int right(char *str, char *search)
{
	char *find;
	return ((find = strstr(str, search)) && (strcasecmp(find, search) == 0));
}

static int file_exists(char *path)
{
	struct stat statbuf;
	if(stat(path, &statbuf) < 0) {
		if(errno == ENOENT) {
			return 0;
		} else {
			fprintf(stderr, "could not stat %s\n", path);
			perror("");
			exit(0);
		}
	}
	return 1;
}

void iweather_scan(const char *dirname)
{
	int i;
	char buffer[100];
	DIR *dir = opendir(dirname);
	struct dirent *wdir;
	if(!dir) {
		return;
	}
	i = 0;
	while (wdir = readdir(dir))
	{
		if (right(wdir->d_name, ".png"))
		{
			ttk_menu_item *item = calloc (1, sizeof(struct ttk_menu_item));
			snprintf(buffer, strlen(wdir->d_name)-3, "%s", wdir->d_name);
			item->name = strdup(buffer);
			//item->data = (void *)i;
			ttk_menu_append(menu, item);
		}
	}
	closedir(dir);
}

static void iweather_show(char *filename)
{
	char buffer[256];
#ifdef IPOD
	sprintf(buffer, "/iweather/%s.png", filename);
	if(file_exists(buffer)){
		image = ttk_load_image (buffer);
	}
	else{
		sprintf(buffer, "/mnt/iweather/%s.png", filename);
		if(file_exists(buffer)){
			image = ttk_load_image (buffer);
		}
		else{
			sprintf(buffer, "/hp/iweather/%s.png", filename);
			if(file_exists(buffer)){
				image = ttk_load_image (buffer);
			}
		}
	}
#else
	sprintf(buffer, "./iweather/%s.png", filename);
	if(file_exists(buffer)){
		image = ttk_load_image (buffer);
	}
	else{
		return;
	}
#endif
	if (viewer_window == NULL){
		viewer_window = ttk_new_window();
	}

	if (viewer != NULL)
	{
		ttk_remove_widget(viewer_window, viewer);
		ttk_free_widget(viewer);
	}

	viewer = ttk_new_imgview_widget (ttk_screen->w, ttk_screen->h, image);
	
	ttk_window_hide_header(viewer_window);
	ttk_add_widget(viewer_window, viewer);
	ttk_window_set_title(viewer_window, filename);
	ttk_show_window(viewer_window);
}

static int iweather_menu_down(TWidget *this, int button)
{
	if (button == TTK_BUTTON_ACTION && ttk_menu_get_selected_item(this) != 0)
	{
		char *filename = (char *)(ttk_menu_get_selected_item(this)->name);
        	iweather_show(filename);
	}
	return ttk_menu_down(this, button);
}

static TWindow * iweather_new_window() 
{
	window = pz_new_window ("iWeather", PZ_WINDOW_NORMAL);

	menu = ttk_new_menu_widget(0, ttk_menufont, ttk_screen->w - ttk_screen->wx, ttk_screen->h - ttk_screen->wy);
	menu->down = iweather_menu_down;
	ttk_menu_clear(menu);

#ifdef IPOD
	if(file_exists("/iweather")){
		iweather_scan("/iweather");
	}
	else if(file_exists("/mnt/iweather")){
		iweather_scan("/mnt/iweather");
	}
	else{
		iweather_scan("/hp/iweather");
	}
#else
	iweather_scan("./iweather");
#endif

	ttk_add_widget (window, menu);
	return pz_finish_window (window);
}

void iweather_init()
{
	module = pz_register_module ("iweather", NULL);

	//config = pz_load_config(pz_module_get_cfgpath(module, "iweather.conf"));

	pz_menu_add_action ("/Extras/Utilities/iWeather/View", iweather_new_window);
	//pz_menu_add_setting("/Extras/Utilities/iWeather/Load From", 1, config, loading_options);
}

PZ_MOD_INIT (iweather_init)
